@@ -13,12 +13,8 @@ class TestModel(unittest.TestCase):
         shutil.rmtree("./data/original_datasets")
         self.gpf = GPF('prison', self.data)
 
-    @classmethod
-    def tearDownClass(cls):
-        shutil.rmtree("./results")
-
     def test_calculate_metrics_dict(self):
         model, like = self.gpf.train(n_iterations=100)
-        mean, lower, upper = self.gpf.predict(model, like)
-        res = self.gpf.metrics(mean, lower, upper)
+        samples = self.gpf.predict(model, like)
+        res = self.gpf.metrics(samples)
         self.assertLess(res['mase']['bottom'], 2.5)
