@@ -13,27 +13,23 @@ class TestModel(unittest.TestCase):
         shutil.rmtree("./data/original_datasets")
         self.gpf = GPF('prison', self.data)
 
-    @classmethod
-    def tearDownClass(cls):
-        shutil.rmtree("./results")
-
     def test_correct_train(self):
         model, like = self.gpf.train(n_iterations=10)
         self.assertIsNotNone(model)
 
     def test_predict_shape(self):
         model, like = self.gpf.train(n_iterations=10)
-        mean, lower, upper = self.gpf.predict(model, like)
-        self.assertTrue(mean.shape == (1, self.n, self.s))
+        samples = self.gpf.predict(model, like)
+        self.assertTrue(samples.shape == (self.n, self.s, 500))
 
     def test_results_interval(self):
         model, like = self.gpf.train(n_iterations=100)
-        mean, lower, upper = self.gpf.predict(model, like)
-        res = self.gpf.metrics(mean, lower, upper)
+        samples = self.gpf.predict(model, like)
+        res = self.gpf.metrics(samples)
         self.assertLess(res['mase']['bottom'], 2.5)
 
     def test_wall_time(self):
         model, like = self.gpf.train(n_iterations=10)
-        mean, lower, upper = self.gpf.predict(model, like)
-        res = self.gpf.metrics(mean)
+        samples = self.gpf.predict(model, like)
+        res = self.gpf.metrics(samples)
         self.assertLess(res['wall_time']['wall_time_total'], 100)
